==> zio-aws-lookoutequipment_2.12-5.17.130.1-sources.jar: zio/aws/lookoutequipment/model/package.scala <==
package zio.aws.lookoutequipment
import zio.prelude.Subtype
import zio.aws.lookoutequipment.model.primitives.TagKey
import java.time.Instant
import zio.aws.lookoutequipment.model.primitives.KmsKeyArn.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmazonResourceArn extends Subtype[String]
    type AmazonResourceArn =
      zio.aws.lookoutequipment.model.primitives.AmazonResourceArn.Type
    object BoundedLengthString extends Subtype[String]
    type BoundedLengthString =
      zio.aws.lookoutequipment.model.primitives.BoundedLengthString.Type
    object ComponentTimestampDelimiter extends Subtype[String]
    type ComponentTimestampDelimiter =
      zio.aws.lookoutequipment.model.primitives.ComponentTimestampDelimiter.Type
    object DataDelayOffsetInMinutes extends Subtype[Long]
    type DataDelayOffsetInMinutes =
      zio.aws.lookoutequipment.model.primitives.DataDelayOffsetInMinutes.Type
    object DatasetArn extends Subtype[String]
    type DatasetArn = zio.aws.lookoutequipment.model.primitives.DatasetArn.Type
    object DatasetIdentifier extends Subtype[String]
    type DatasetIdentifier =
      zio.aws.lookoutequipment.model.primitives.DatasetIdentifier.Type
    object DatasetName extends Subtype[String]
    type DatasetName =
      zio.aws.lookoutequipment.model.primitives.DatasetName.Type
    object FileNameTimestampFormat extends Subtype[String]
    type FileNameTimestampFormat =
      zio.aws.lookoutequipment.model.primitives.FileNameTimestampFormat.Type
    object IamRoleArn extends Subtype[String]
    type IamRoleArn = zio.aws.lookoutequipment.model.primitives.IamRoleArn.Type
    object IdempotenceToken extends Subtype[String]
    type IdempotenceToken =
      zio.aws.lookoutequipment.model.primitives.IdempotenceToken.Type
    object InferenceSchedulerArn extends Subtype[String]
    type InferenceSchedulerArn =
      zio.aws.lookoutequipment.model.primitives.InferenceSchedulerArn.Type
    object InferenceSchedulerIdentifier extends Subtype[String]
    type InferenceSchedulerIdentifier =
      zio.aws.lookoutequipment.model.primitives.InferenceSchedulerIdentifier.Type
    object InferenceSchedulerName extends Subtype[String]
    type InferenceSchedulerName =
      zio.aws.lookoutequipment.model.primitives.InferenceSchedulerName.Type
    object IngestionJobId extends Subtype[String]
    type IngestionJobId =
      zio.aws.lookoutequipment.model.primitives.IngestionJobId.Type
    object InlineDataSchema extends Subtype[String]
    type InlineDataSchema =
      zio.aws.lookoutequipment.model.primitives.InlineDataSchema.Type
    object KmsKeyArn extends Subtype[String]
    type KmsKeyArn = zio.aws.lookoutequipment.model.primitives.KmsKeyArn.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.lookoutequipment.model.primitives.MaxResults.Type
    object ModelArn extends Subtype[String]
    type ModelArn = zio.aws.lookoutequipment.model.primitives.ModelArn.Type
    object ModelMetrics extends Subtype[String]
    type ModelMetrics =
      zio.aws.lookoutequipment.model.primitives.ModelMetrics.Type
    object ModelName extends Subtype[String]
    type ModelName = zio.aws.lookoutequipment.model.primitives.ModelName.Type
    object NameOrArn extends Subtype[String]
    type NameOrArn = zio.aws.lookoutequipment.model.primitives.NameOrArn.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.lookoutequipment.model.primitives.NextToken.Type
    object OffCondition extends Subtype[String]
    type OffCondition =
      zio.aws.lookoutequipment.model.primitives.OffCondition.Type
    object S3Bucket extends Subtype[String]
    type S3Bucket = zio.aws.lookoutequipment.model.primitives.S3Bucket.Type
    object S3Key extends Subtype[String]
    type S3Key = zio.aws.lookoutequipment.model.primitives.S3Key.Type
    object S3Prefix extends Subtype[String]
    type S3Prefix = zio.aws.lookoutequipment.model.primitives.S3Prefix.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.lookoutequipment.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.lookoutequipment.model.primitives.TagValue.Type
    object TimeZoneOffset extends Subtype[String]
    type TimeZoneOffset =
      zio.aws.lookoutequipment.model.primitives.TimeZoneOffset.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.lookoutequipment.model.primitives.Timestamp.Type
  }
  type DataIngestionJobSummaries =
    List[zio.aws.lookoutequipment.model.DataIngestionJobSummary]
  type DatasetSummaries = List[zio.aws.lookoutequipment.model.DatasetSummary]
  type InferenceExecutionSummaries =
    List[zio.aws.lookoutequipment.model.InferenceExecutionSummary]
  type InferenceSchedulerSummaries =
    List[zio.aws.lookoutequipment.model.InferenceSchedulerSummary]
  type ModelSummaries = List[zio.aws.lookoutequipment.model.ModelSummary]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.lookoutequipment.model.Tag]
}

==> zio-aws-lookoutequipment_2.12-5.20.7.3-sources.jar: zio/aws/lookoutequipment/model/package.scala <==
package zio.aws.lookoutequipment
import zio.prelude.Subtype
import zio.aws.lookoutequipment.model.primitives.{TagKey, FaultCode}
import java.time.Instant
import zio.aws.lookoutequipment.model.primitives.KmsKeyArn.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object AmazonResourceArn extends Subtype[String]
    type AmazonResourceArn =
      zio.aws.lookoutequipment.model.primitives.AmazonResourceArn.Type
    object BoundedLengthString extends Subtype[String]
    type BoundedLengthString =
      zio.aws.lookoutequipment.model.primitives.BoundedLengthString.Type
    object Comments extends Subtype[String]
    type Comments = zio.aws.lookoutequipment.model.primitives.Comments.Type
    object ComponentName extends Subtype[String]
    type ComponentName =
      zio.aws.lookoutequipment.model.primitives.ComponentName.Type
    object ComponentTimestampDelimiter extends Subtype[String]
    type ComponentTimestampDelimiter =
      zio.aws.lookoutequipment.model.primitives.ComponentTimestampDelimiter.Type
    object DataDelayOffsetInMinutes extends Subtype[Long]
    type DataDelayOffsetInMinutes =
      zio.aws.lookoutequipment.model.primitives.DataDelayOffsetInMinutes.Type
    object DataSizeInBytes extends Subtype[Long]
    type DataSizeInBytes =
      zio.aws.lookoutequipment.model.primitives.DataSizeInBytes.Type
    object DatasetArn extends Subtype[String]
    type DatasetArn = zio.aws.lookoutequipment.model.primitives.DatasetArn.Type
    object DatasetIdentifier extends Subtype[String]
    type DatasetIdentifier =
      zio.aws.lookoutequipment.model.primitives.DatasetIdentifier.Type
    object DatasetName extends Subtype[String]
    type DatasetName =
      zio.aws.lookoutequipment.model.primitives.DatasetName.Type
    object Equipment extends Subtype[String]
    type Equipment = zio.aws.lookoutequipment.model.primitives.Equipment.Type
    object EventDurationInSeconds extends Subtype[Long]
    type EventDurationInSeconds =
      zio.aws.lookoutequipment.model.primitives.EventDurationInSeconds.Type
    object FaultCode extends Subtype[String]
    type FaultCode = zio.aws.lookoutequipment.model.primitives.FaultCode.Type
    object FileNameTimestampFormat extends Subtype[String]
    type FileNameTimestampFormat =
      zio.aws.lookoutequipment.model.primitives.FileNameTimestampFormat.Type
    object IamRoleArn extends Subtype[String]
    type IamRoleArn = zio.aws.lookoutequipment.model.primitives.IamRoleArn.Type
    object IdempotenceToken extends Subtype[String]
    type IdempotenceToken =
      zio.aws.lookoutequipment.model.primitives.IdempotenceToken.Type
    object InferenceSchedulerArn extends Subtype[String]
    type InferenceSchedulerArn =
      zio.aws.lookoutequipment.model.primitives.InferenceSchedulerArn.Type
    object InferenceSchedulerIdentifier extends Subtype[String]
    type InferenceSchedulerIdentifier =
      zio.aws.lookoutequipment.model.primitives.InferenceSchedulerIdentifier.Type
    object InferenceSchedulerName extends Subtype[String]
    type InferenceSchedulerName =
      zio.aws.lookoutequipment.model.primitives.InferenceSchedulerName.Type
    object IngestionJobId extends Subtype[String]
    type IngestionJobId =
      zio.aws.lookoutequipment.model.primitives.IngestionJobId.Type
    object InlineDataSchema extends Subtype[String]
    type InlineDataSchema =
      zio.aws.lookoutequipment.model.primitives.InlineDataSchema.Type
    type Integer = Int
    object KeyPattern extends Subtype[String]
    type KeyPattern = zio.aws.lookoutequipment.model.primitives.KeyPattern.Type
    object KmsKeyArn extends Subtype[String]
    type KmsKeyArn = zio.aws.lookoutequipment.model.primitives.KmsKeyArn.Type
    object LabelGroupArn extends Subtype[String]
    type LabelGroupArn =
      zio.aws.lookoutequipment.model.primitives.LabelGroupArn.Type
    object LabelGroupName extends Subtype[String]
    type LabelGroupName =
      zio.aws.lookoutequipment.model.primitives.LabelGroupName.Type
    object LabelId extends Subtype[String]
    type LabelId = zio.aws.lookoutequipment.model.primitives.LabelId.Type
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.lookoutequipment.model.primitives.MaxResults.Type
    object ModelArn extends Subtype[String]
    type ModelArn = zio.aws.lookoutequipment.model.primitives.ModelArn.Type
    object ModelMetrics extends Subtype[String]
    type ModelMetrics =
      zio.aws.lookoutequipment.model.primitives.ModelMetrics.Type
    object ModelName extends Subtype[String]
    type ModelName = zio.aws.lookoutequipment.model.primitives.ModelName.Type
    object NameOrArn extends Subtype[String]
    type NameOrArn = zio.aws.lookoutequipment.model.primitives.NameOrArn.Type
    object NextToken extends Subtype[String]
    type NextToken = zio.aws.lookoutequipment.model.primitives.NextToken.Type
    object OffCondition extends Subtype[String]
    type OffCondition =
      zio.aws.lookoutequipment.model.primitives.OffCondition.Type
    object S3Bucket extends Subtype[String]
    type S3Bucket = zio.aws.lookoutequipment.model.primitives.S3Bucket.Type
    object S3Key extends Subtype[String]
    type S3Key = zio.aws.lookoutequipment.model.primitives.S3Key.Type
    object S3Prefix extends Subtype[String]
    type S3Prefix = zio.aws.lookoutequipment.model.primitives.S3Prefix.Type
    object SensorName extends Subtype[String]
    type SensorName = zio.aws.lookoutequipment.model.primitives.SensorName.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.lookoutequipment.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.lookoutequipment.model.primitives.TagValue.Type
    object TimeZoneOffset extends Subtype[String]
    type TimeZoneOffset =
      zio.aws.lookoutequipment.model.primitives.TimeZoneOffset.Type
    object Timestamp extends Subtype[Instant]
    type Timestamp = zio.aws.lookoutequipment.model.primitives.Timestamp.Type
  }
  type DataIngestionJobSummaries =
    List[zio.aws.lookoutequipment.model.DataIngestionJobSummary]
  type DatasetSummaries = List[zio.aws.lookoutequipment.model.DatasetSummary]
  type FaultCodes = List[FaultCode]
  type InferenceEventSummaries =
    List[zio.aws.lookoutequipment.model.InferenceEventSummary]
  type InferenceExecutionSummaries =
    List[zio.aws.lookoutequipment.model.InferenceExecutionSummary]
  type InferenceSchedulerSummaries =
    List[zio.aws.lookoutequipment.model.InferenceSchedulerSummary]
  type LabelGroupSummaries =
    List[zio.aws.lookoutequipment.model.LabelGroupSummary]
  type LabelSummaries = List[zio.aws.lookoutequipment.model.LabelSummary]
  type ListOfDiscardedFiles = List[zio.aws.lookoutequipment.model.S3Object]
  type ModelSummaries = List[zio.aws.lookoutequipment.model.ModelSummary]
  type SensorStatisticsSummaries =
    List[zio.aws.lookoutequipment.model.SensorStatisticsSummary]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.lookoutequipment.model.Tag]
}
